@@ -60,6 +60,8 @@ pub mod octo_generic_event;
 pub use self::octo_generic_event::OctoGenericEvent;
 pub mod octo_job_event;
 pub use self::octo_job_event::OctoJobEvent;
+pub mod octo_print_backup;
+pub use self::octo_print_backup::OctoPrintBackup;
 pub mod octo_print_device;
 pub use self::octo_print_device::OctoPrintDevice;
 pub mod octo_print_device_key;
@@ -140,6 +142,8 @@ pub mod paginated_license_list;
 pub use self::paginated_license_list::PaginatedLicenseList;
 pub mod paginated_model_artifact_list;
 pub use self::paginated_model_artifact_list::PaginatedModelArtifactList;
+pub mod paginated_octo_print_backup_list;
+pub use self::paginated_octo_print_backup_list::PaginatedOctoPrintBackupList;
 pub mod paginated_octo_print_device_list;
 pub use self::paginated_octo_print_device_list::PaginatedOctoPrintDeviceList;
 pub mod paginated_octo_print_event_list;
